#!/usr/bin/bash
if (( $# < 1 )); then
	echo "Usage: $0 <branch> optional <for staging 'S' >  <for test build 't'>" >&2
	exit 1
fi
#nastav poslední verzi fedory
fcver1=41
((fcver2 = fcver1 - 1))
((fcver3 = fcver1 - 2))

input1="$1"
input2="$2"
input3="$3"
input4="$4"

if [ "$input2" == "S" ] || [ "$input3" == "S" ] && [ "$input1" != "main" ] ; then
  branch=staging/$1
else
  branch="$1"
fi

if [ "$input3" == "t" ] || [ "$input2" == "t" ]; then
  test=1
else
 test=0
fi

if [ "$input3" == "u" ] || [ "$input2" == "u" ]; then
  upload=1
else
 upload=0
fi

if [ "$input3" == "ur" ] || [ "$input2" == "ur" ]; then
  uploadr=1
else
 uploadr=0
fi

if [ "$input4" == "d" ] || [ "$input3" == "d" ] || [ "$input2" == "d" ]; then
specfile=mesa-devel.spec
specfilefree=mesa-freeworld-devel.spec
else
specfile=mesa.spec
specfilefree=mesa-freeworld.spec
fi


brfolder="$(echo "${branch//\//\-}")"
name=mesa
tarball="mesa-$brfolder"

if [ ! -d "mesa/mesa-$brfolder" ]; then
mkdir -p mesa
git clone -b $branch https://gitlab.freedesktop.org/mesa/mesa.git mesa/$name-$brfolder
fi

pushd mesa/$tarball
git pull >&/dev/null
onserver="$(git rev-parse --short HEAD)"
gitbranch="$(git rev-parse --abbrev-ref HEAD)"
mesaversion=$(cat VERSION)
mesaver="$(echo "${mesaversion/-/'~'}")"
downloaded="$(echo `find ../../$name-$mesaversion-*.tar.xz` | awk -F'-*.tar.xz' '{print $1}' | awk -F"$name-$mesaversion-" '{print $NF}')"

  if [ "$downloaded" != "$onserver" ] ; then
 
    sed -i "/define gittag /c\%define gittag $onserver" ../../../SPECS/$specfile
    sed -i "/%global ver /c\%global ver $mesaversion" ../../../SPECS/$specfile

    sed -i "/define gittag /c\%define gittag $onserver" ../../../SPECS/$specfilefree
    sed -i "/%global ver /c\%global ver $mesaversion" ../../../SPECS/$specfilefree

  printf "branch: \e[31;4m$gitbranch\e[0m\n"
  echo "onserver: $onserver"
  echo "...."
  rm -f ../../$name-$mesaversion-*.tar.xz
  git config --global tar.tar.xz.command 'xz -c'
  git archive --prefix=$name-$mesaversion/ --output=../../$name-$mesaversion-$onserver.tar.xz  HEAD
  rpmdev-bumpspec ../../../SPECS/$specfile -c "update to git $onserver"
  rpmbuild -bs ../../../SPECS/$specfile
  rpmdev-bumpspec ../../../SPECS/$specfilefree -c "update to git $onserver"
  rpmbuild -bs ../../../SPECS/$specfilefree

else
  printf "$tarball no need update\n"
fi

popd

if [ "$upload" == 1 ]; then
copr-cli build mesa --chroot fedora-$fcver1-i386 --chroot fedora-$fcver1-x86_64 --chroot fedora-$fcver2-i386 --chroot fedora-$fcver2-x86_64 --chroot fedora-$fcver3-i386 --chroot fedora-$fcver3-x86_64 --chroot fedora-rawhide-x86_64 --chroot fedora-rawhide-i386 ../SRPMS/$name-*$onserver*.rpm
fi

if [ "$uploadr" == 1 ]; then
copr-cli build mesa --chroot fedora-$fcver1-i386 --chroot fedora-$fcver1-x86_64 --chroot fedora-$fcver2-i386 --chroot fedora-$fcver2-x86_64 --chroot fedora-rawhide-x86_64 --chroot fedora-rawhide-i386 ../SRPMS/$name-*$onserver*.rpm
fi

if [ "$test" == 1 ]; then
echo "$PWD"
pushd mesa/$tarball
onserver="$(git rev-parse --short HEAD)"
gitbranch="$(git rev-parse --abbrev-ref HEAD)"
popd
#sed -i "/%bcond_with test/c\%bcond_without test" ../SPECS/$specfile
  rpmbuild -bs ../SPECS/$specfile
  mock -r fedora-$fcver1-x86_64 --resultdir=~/mock/x64 ../SRPMS/$name-$mesaver*$onserver*.rpm
  #mock -r fedora-$fcver1-i386 --resultdir=~/mock/x32 ../SRPMS/$name-*$onserver*.rpm
#sed -i "/%bcond_without test/c\%bcond_with test" ../SPECS/$specfile
#rpmbuild -bs ../SPECS/$specfile
fi
